Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(66)

Unified Diff: chrome/common/metrics/version_utils.h

Issue 1257633002: Componentize VersionInfo. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Convert version_info::Channel to a "class enum" Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/gcm_desktop_util.cc ('k') | chrome/common/metrics/version_utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/metrics/version_utils.h
diff --git a/chrome/common/metrics/version_utils.h b/chrome/common/metrics/version_utils.h
index f1491a1e27ed7f76125564e82d26684b85d9ed23..389c22791dbaa9320584ed82cefe418a288ea666 100644
--- a/chrome/common/metrics/version_utils.h
+++ b/chrome/common/metrics/version_utils.h
@@ -16,10 +16,10 @@ namespace metrics {
// platforms, and "-devel" on developer builds.
std::string GetVersionString();
// Translates chrome::VersionInfo::Channel to the equivalent
// SystemProfileProto::Channel.
SystemProfileProto::Channel AsProtobufChannel(
- chrome::VersionInfo::Channel channel);
+ version_info::Channel channel);
} // namespace metrics
« no previous file with comments | « chrome/common/gcm_desktop_util.cc ('k') | chrome/common/metrics/version_utils.cc » ('j') | no next file with comments »
@@ -16,10 +16,10 @@ namespace metrics {
// platforms, and "-devel" on developer builds.
std::string GetVersionString();
-// Translates chrome::VersionInfo::Channel to the equivalent
+// Translates version_info::Channel to the equivalent
// SystemProfileProto::Channel.
SystemProfileProto::Channel AsProtobufChannel(

Powered by Google App Engine
This is Rietveld 408576698